@@ -255,6 +255,15 @@ def show_archives():
         logging.info(value.name())
 
 
+@click.command()
+@transaction.atomic()
+def process_members():
+    """Process each member"""
+    import exporter
+
+    exporter.generate_report()
+
+
 @click.command()
 @click.argument("issn")
 @transaction.atomic()
@@ -435,6 +444,7 @@ if __name__ == "__main__":
     cli.add_command(import_ocul)
     cli.add_command(import_pkp)
     cli.add_command(import_portico)
+    cli.add_command(process_members)
     cli.add_command(random_samples)
     cli.add_command(show_archives)
     cli.add_command(show_cache)
