@@ -113,7 +113,12 @@ class LockssPreservation(models.Model):
 
     @staticmethod
     def preservation(
-        container_title: str, issn: str, volume: str, no=None, year=None
+        container_title: str,
+        issn: str,
+        volume: str,
+        no=None,
+        year=None,
+        doi=None,
     ):
         """
         Determine whether a DOI is preserved in LOCKSS
@@ -122,6 +127,7 @@ class LockssPreservation(models.Model):
         :param volume: the volume
         :param no: the issue number
         :param year: the year
+        :param doi: a DOI
         :return: A LockssPreservation item (or None) and a bool indicating
         whether the item is fully preserved
         """
@@ -220,7 +226,12 @@ class CarinianaPreservation(models.Model):
 
     @staticmethod
     def preservation(
-        container_title: str, issn: str, volume: str, no=None, year=None
+        container_title: str,
+        issn: str,
+        volume: str,
+        no=None,
+        year=None,
+        doi=None,
     ):
         """
         Determine whether a DOI is preserved in Cariniana
@@ -229,6 +240,7 @@ class CarinianaPreservation(models.Model):
         :param volume: the volume
         :param no: the issue number
         :param year: the year
+        :param doi: a DOI
         :return: A Cariniana item (or None) and a bool indicating
         whether the item is fully preserved
         """
@@ -327,7 +339,12 @@ class ClockssPreservation(models.Model):
 
     @staticmethod
     def preservation(
-        container_title: str, issn: str, volume: str, no=None, year=None
+        container_title: str,
+        issn: str,
+        volume: str,
+        no=None,
+        year=None,
+        doi=None,
     ):
         """
         Determine whether a DOI is preserved in CLOCKSS
@@ -336,6 +353,7 @@ class ClockssPreservation(models.Model):
         :param volume: the volume
         :param no: the issue number
         :param year: the year
+        :param doi: a DOI
         :return: A ClockssPreservation item (or None) and a bool indicating
         whether the item is fully preserved
         """
@@ -423,7 +441,7 @@ class PKPPreservation(models.Model):
         return "PKP PLN"
 
     @staticmethod
-    def preservation(container_title, issn, volume, no, year=None):
+    def preservation(container_title, issn, volume, no, year=None, doi=None):
         """
         Determine whether a DOI is preserved in the PKP private LOCKSS network
         :param container_title: the container title
@@ -431,6 +449,7 @@ class PKPPreservation(models.Model):
         :param volume: the volume
         :param no: the issue number
         :param year: the year
+        :param doi: a DOI
         :return: A PKPPreservation item (or None) and a bool indicating
         whether the item is fully preserved
         """
@@ -507,7 +526,9 @@ class HathiPreservation(models.Model):
         return "HathiTrust"
 
     @staticmethod
-    def preservation(container_title, issn, volume, no=None, year=None):
+    def preservation(
+        container_title, issn, volume, no=None, year=None, doi=None
+    ):
         """
         Determine whether a DOI is preserved in HathiTrust
         :param container_title: the container title
@@ -515,6 +536,7 @@ class HathiPreservation(models.Model):
         :param volume: the volume
         :param no: the issue number
         :param year: the year
+        :param doi: a DOI
         :return: A HathiPreservation item (or None) and a bool indicating
         whether the item is fully preserved
         """
@@ -699,7 +721,9 @@ class PorticoPreservation(models.Model):
         return "Portico"
 
     @staticmethod
-    def preservation(container_title, issn, volume, no=None, year=None):
+    def preservation(
+        container_title, issn, volume, no=None, year=None, doi=None
+    ):
         """
         Determine whether a DOI is preserved in Portico
         :param container_title: the container title
@@ -707,6 +731,7 @@ class PorticoPreservation(models.Model):
         :param volume: the volume
         :param no: the issue number
         :param year: the year
+        :param doi: a DOI
         :return: A PorticoPreservation item (or None) and a bool indicating
         whether the item is fully preserved
         """
@@ -837,7 +862,9 @@ class OculScholarsPortalPreservation(models.Model):
         return "OCUL Scholars Portal"
 
     @staticmethod
-    def preservation(container_title, issn, volume, no=None, year=None):
+    def preservation(
+        container_title, issn, volume, no=None, year=None, doi=None
+    ):
         """
         Determine whether a DOI is preserved in OCUL Scholars Portal
         :param container_title: the container title
@@ -845,6 +872,7 @@ class OculScholarsPortalPreservation(models.Model):
         :param volume: the volume
         :param no: the issue number
         :param year: the year
+        :param doi: a DOI
         :return: An OculScholarsPortalPreservation item (or None) and a bool
         indicating whether the item is fully preserved
         """
@@ -1046,7 +1074,9 @@ class InternetArchivePreservation(models.Model):
         return "Internet Archive"
 
     @staticmethod
-    def preservation(container_title, issn, volume, no=None, year=None):
+    def preservation(
+        container_title, issn, volume, no=None, year=None, doi=None
+    ):
         """
         Determine whether a DOI is preserved in the Internet Archive
         :param container_title: the container title
@@ -1054,6 +1084,7 @@ class InternetArchivePreservation(models.Model):
         :param volume: the volume
         :param no: the issue number
         :param year: the year
+        :param doi: a DOI
         :return: An InternetArchivePreservation item (or None) and a bool
         indicating whether the item is fully preserved
         """
@@ -1166,6 +1197,15 @@ class InternetArchiveItem(models.Model):
     url = models.TextField()
     fatcat_ident = models.TextField()
 
+    def __str__(self):
+        return "{} (url: {}) (fatcat: {})".format(
+            self.doi, self.url, self.fatcat_ident
+        )
+
+    @staticmethod
+    def name():
+        return "Internet Archive Scholar (item-level data)"
+
     @staticmethod
     def import_data(file: str) -> None:
         """Imports data from an Internet Archive file. Updates are propagated
@@ -1256,3 +1296,28 @@ class InternetArchiveItem(models.Model):
                 progress.console.print(f"Flushing {len(batch_objects)} items.")
 
             return
+
+    @staticmethod
+    def preservation(
+        container_title, issn, volume, no=None, year=None, doi=None
+    ):
+        """
+        Determine whether a DOI is preserved in the Internet Archive
+        :param container_title: the container title
+        :param issn: the ISSN
+        :param volume: the volume
+        :param no: the issue number
+        :param year: the year
+        :param doi: a DOI
+        :return: An InternetArchiveItem item (or None) and a bool
+        indicating whether the item is fully preserved
+        """
+        try:
+            preserved_item = InternetArchiveItem.objects.filter(doi=doi["DOI"])
+
+            if len(preserved_item) > 0:
+                return preserved_item[0], True
+            else:
+                return None, False
+        except InternetArchiveItem.DoesNotExist:
+            return None, False
