@@ -103,7 +103,7 @@ def show_preservation(
 
     for system in preservation_systems:
         preserved, done = system.preservation(
-            container_title, final_issn_list, volume, no, year
+            container_title, final_issn_list, volume, no=no, year=year, doi=doi
         )
         preservations[system.name()] = preserved, done
 
